BagEndsConfig = {}

local BagEndsFrame = CreateFrame( "Frame", "BagEndsConfigFrame", InterfaceOptionsFramePanelContainer)
local Title = BagEndsConfigFrame:CreateFontString( "BagEndsTitle", nil, "GameFontNormalLarge")
local OutlineToggle = CreateFrame( "CheckButton", "BagEndsOutlineToggle", BagEndsFrame, "InterfaceOptionsCheckButtonTemplate" )
local TextToggle = CreateFrame( "CheckButton", "BagEndsTextToggle", BagEndsFrame, "InterfaceOptionsCheckButtonTemplate" )
local ColorToggle = CreateFrame( "CheckButton", "BagEndsColorToggle", BagEndsFrame, "InterfaceOptionsCheckButtonTemplate" )
local OccupiedToggle = CreateFrame( "CheckButton", "BagEndsOccupiedToggle", BagEndsFrame, "InterfaceOptionsCheckButtonTemplate" )
local ShowTotalToggle = CreateFrame( "CheckButton", "BagEndsTotalToggle", BagEndsFrame, "InterfaceOptionsCheckButtonTemplate" )
local InventoryToggle = CreateFrame( "CheckButton", "BagEndsInventoryToggle", BagEndsFrame, "InterfaceOptionsCheckButtonTemplate" )
local BankToggle = CreateFrame( "CheckButton", "BagEndsBankToggle", BagEndsFrame, "InterfaceOptionsCheckButtonTemplate" )
local EmptyToggle = CreateFrame( "CheckButton", "BagEndsEmptyToggle", BagEndsFrame, "InterfaceOptionsCheckButtonTemplate" )
local GeneralHeader = BagEndsConfigFrame:CreateFontString( "BagEndsGeneralHeader", nil, "GameFontNormal")
local DisplayHeader = BagEndsConfigFrame:CreateFontString( "BagEndsDisplayHeader", nil, "GameFontNormal")

local function SetDefaults()
	BagEndsConfig.outline = true
	BagEndsConfig.showText = true
	BagEndsConfig.colorText = false
	BagEndsConfig.occupied = false
	BagEndsConfig.showTotal = true
	BagEndsConfig.inventory = true
	BagEndsConfig.bank = true
	BagEndsConfig.lowerBagLimit = 1
	BagEndsConfig.upperBagLimit = 12
	BagEndsConfig.savedVariables = true
	BagEndsConfig.hideEmpty = true
end

local function SpewMessage(handle, msg)
	if handle == "loaded" then
		print("|cFFFFCC00" .. GetAddOnMetadata("BagEnds", "Title") .. "|r v|cFF00FF00" .. GetAddOnMetadata("BagEnds", "Version") .. "|r " .. BE_LOADMSG1 .. " |cAAFFCC00" .. SLASH_BAGENDS1 .. "|r " .. BE_LOADMSG2 .. " |cAAFFCC00" .. SLASH_BAGENDS2 .. "|r " .. BE_LOADMSG3)
	elseif handle == "help" then
		print(BE_HELPMSG1 .. " |cFFFFCC00" .. SLASH_BAGENDS1 .. "|r " .. BE_HELPMSG2 .. " |cFFFFCC00" .. SLASH_BAGENDS2 .. "|r " .. BE_HELPMSG3)
		SpewMessage(BE_CONFIG, BE_CONFIGTOOLTIP)
		SpewMessage(BE_INVENTORY, BE_INVENTORYTOOLTIP)
		SpewMessage(BE_BANK, BE_BANKTOOLTIP)
		SpewMessage(BE_OUTLINE, BE_OUTLINETOOLTIP)
		SpewMessage(BE_TEXT, BE_TEXTTOOLTIP)
		SpewMessage(BE_COLOR, BE_COLORTOOLTIP)
		SpewMessage(BE_FREE, BE_FREETOOLTIP)
		SpewMessage(BE_TOTAL, BE_TOTALTOOLTIP)
		SpewMessage(BE_EMPTY, BE_EMPTYTOOLTIP)
	else
		print("|cFFFFCC00" .. handle .. "|r - " .. msg)
	end
end

local function UpdateConfig()
	
	BagEndsConfig.outline = BagEndsOutlineToggle:GetChecked()
	BagEndsConfig.showText = BagEndsTextToggle:GetChecked()
	BagEndsConfig.inventory = BagEndsInventoryToggle:GetChecked()
	BagEndsConfig.bank = BagEndsBankToggle:GetChecked()
	BagEndsConfig.hideEmpty = BagEndsEmptyToggle:GetChecked()
	
	if (BagEndsConfig.bank) then
		BagEndsConfig.upperBagLimit = 12
	else
		BagEndsConfig.upperBagLimit = 5
	end
	if (BagEndsConfig.inventory) then
		BagEndsConfig.lowerBagLimit = 1
	else
		BagEndsConfig.lowerBagLimit = 6
	end
	
	if (BagEndsConfig.showText) then
		
		BagEndsColorToggle:Enable()
		BagEndsOccupiedToggle:Enable()
		BagEndsTotalToggle:Enable()
		
		BagEndsConfig.colorText = BagEndsColorToggle:GetChecked()
		BagEndsConfig.occupied = BagEndsOccupiedToggle:GetChecked()
		BagEndsConfig.showTotal = BagEndsTotalToggle:GetChecked()
	
	else
	
		BagEndsColorToggle:Disable()
		BagEndsOccupiedToggle:Disable()
		BagEndsTotalToggle:Disable()
		
	end

	for i = BagEndsConfig.lowerBagLimit, BagEndsConfig.upperBagLimit do
			BagStringNames[i]:Show()
			BagOutlineNames[i]:Show()
	end
	if (not BagEndsConfig.inventory) then
		for i = 1, 5 do
			BagStringNames[i]:Hide()
			BagOutlineNames[i]:Hide()
		end
	end
	if (not BagEndsConfig.bank) then
		for i = 6, 12 do
			BagStringNames[i]:Hide()
			BagOutlineNames[i]:Hide()
		end
	end
	BagEndsUpdate()
end

local function BagEndsConfigInit()
	BagEndsFrame.name = "Bag Ends"
 
	BagEndsTitle:SetPoint("TOP", 0, -16)
	BagEndsTitle:SetText(GetAddOnMetadata("BagEnds", "Title") .. " v" .. GetAddOnMetadata("BagEnds", "Version"))
 
 	BagEndsGeneralHeader:SetPoint("TOPLEFT", 32,-46)
	BagEndsGeneralHeader:SetText(BE_GENERALHEADER)
  	
	BagEndsBankToggle:SetPoint( "TOPLEFT", 32, -70 )
	BagEndsBankToggle:SetScript("OnClick", UpdateConfig)
	BagEndsBankToggle:SetChecked(BagEndsConfig.bank)
	BagEndsBankToggleText:SetText(BE_BANKTOGGLE)
	BagEndsBankToggle.tooltipText = BE_BANKTOOLTIP
	
	BagEndsInventoryToggle:SetPoint( "TOPLEFT", 32, -102 )
	BagEndsInventoryToggle:SetScript("OnClick", UpdateConfig)
	BagEndsInventoryToggle:SetChecked(BagEndsConfig.inventory)
	BagEndsInventoryToggleText:SetText(BE_INVENTORYTOGGLE)
	BagEndsInventoryToggle.tooltipText = BE_INVENTORYTOOLTIP
 
  	BagEndsDisplayHeader:SetPoint("TOPLEFT", 32,-162)
	BagEndsDisplayHeader:SetText(BE_DISPLAYHEADER)
 
	BagEndsTextToggle:SetPoint( "TOPLEFT", 32, -186 )
	BagEndsTextToggle:SetScript("OnClick", UpdateConfig)
	BagEndsTextToggle:SetChecked(BagEndsConfig.showText)
	BagEndsTextToggleText:SetText(BE_TEXTTOGGLE)
	BagEndsTextToggle.tooltipText = BE_TEXTTOOLTIP
		
	BagEndsColorToggle:SetPoint( "TOPLEFT", 48, -218 )
	BagEndsColorToggle:SetScript("OnClick", UpdateConfig)
	BagEndsColorToggle:SetChecked(BagEndsConfig.colorText)
	BagEndsColorToggleText:SetText(BE_COLORTOGGLE)
	BagEndsColorToggle.tooltipText = BE_COLORTOOLTIP
	
	BagEndsOccupiedToggle:SetPoint( "TOPLEFT", 48, -250 )
	BagEndsOccupiedToggle:SetScript("OnClick", UpdateConfig)
	BagEndsOccupiedToggle:SetChecked(BagEndsConfig.occupied)
	BagEndsOccupiedToggleText:SetText(BE_FREETOGGLE)
	BagEndsOccupiedToggle.tooltipText = BE_FREETOOLTIP
	
	BagEndsTotalToggle:SetPoint( "TOPLEFT", 48, -282 )
	BagEndsTotalToggle:SetScript("OnClick", UpdateConfig)
	BagEndsTotalToggle:SetChecked(BagEndsConfig.showTotal)
	BagEndsTotalToggleText:SetText(BE_TOTALTOGGLE)
	BagEndsTotalToggle.tooltipText = BE_TOTALTOOLTIP

	BagEndsOutlineToggle:SetPoint( "TOPLEFT", 32, -314 )
	BagEndsOutlineToggle:SetScript("OnClick", UpdateConfig)
	BagEndsOutlineToggle:SetChecked(BagEndsConfig.outline)
	BagEndsOutlineToggleText:SetText(BE_OUTLINETOGGLE)
	BagEndsOutlineToggle.tooltipText = BE_OUTLINETOOLTIP
	
	BagEndsEmptyToggle:SetPoint( "TOPLEFT", 32, -346 )
	BagEndsEmptyToggle:SetScript("OnClick", UpdateConfig)
	BagEndsEmptyToggle:SetChecked(BagEndsConfig.hideEmpty)
	BagEndsEmptyToggleText:SetText(BE_EMPTYTOGGLE)
	BagEndsEmptyToggle.tooltipText = BE_EMPTYTOOLTIP
	
	if (BagEndsConfig.showText == false) then
		BagEndsColorToggle:Disable()
		BagEndsOccupiedToggle:Disable()
		BagEndsTotalToggle:Disable()
	end
	
	InterfaceOptions_AddCategory(BagEndsFrame)
end

function BagEndsEventHandler(event, arg1)
	if (BagEndsConfig.savedVariables) then
		BagEndsConfigInit()
	else
		SetDefaults()
		BagEndsConfigInit()
	end
	SpewMessage("loaded")
end

function SlashCmdList.BAGENDS(msg, editbox)
	if msg == BE_CONFIG then
		InterfaceOptionsFrame_OpenToCategory(BagEndsFrame)
	elseif msg == BE_OUTLINE then
		BagEndsOutlineToggle:SetChecked(not BagEndsOutlineToggle:GetChecked())
		UpdateConfig()
	elseif msg == BE_TEXT then
		BagEndsTextToggle:SetChecked(not BagEndsTextToggle:GetChecked())
		UpdateConfig()
	elseif msg == BE_COLOR then
		BagEndsColorToggle:SetChecked(not BagEndsColorToggle:GetChecked())
		UpdateConfig()
	elseif msg == BE_FREE then
		BagEndsOccupiedToggle:SetChecked(not BagEndsOccupiedToggle:GetChecked())
		UpdateConfig()
	elseif msg == BE_TOTAL then
		BagEndsTotalToggle:SetChecked(not BagEndsTotalToggle:GetChecked())
		UpdateConfig()		
	elseif msg == BE_BANK then
		BagEndsBankToggle:SetChecked(not BagEndsBankToggle:GetChecked())
		UpdateConfig()
	elseif msg == BE_INVENTORY then
		BagEndsInventoryToggle:SetChecked(not BagEndsInventoryToggle:GetChecked())
		UpdateConfig()
	elseif msg == BE_EMPTY then
		BagEndsEmptyToggle:SetChecked(not BagEndsEmptyToggle:GetChecked())
		UpdateConfig()
	else
		SpewMessage("help")
	end
end

BagEndsFrame:RegisterEvent("VARIABLES_LOADED")
BagEndsFrame:SetScript("OnEvent", BagEndsEventHandler)